==> bs-platform-0.2.0.tgz: package/jscomp/runtime/caml_int32.ml <==
(* Copyright (C) 2015-2016 Bloomberg Finance L.P.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * In addition to the permissions granted to you by the LGPL, you may combine
 * or link a "work that uses the Library" with a publicly distributed version
 * of this file to produce a combined library or application, then distribute
 * that combined work under the terms of your choosing, with no requirement
 * to comply with the obligations normally placed on you by section 4 of the
 * LGPL version 3 (or the corresponding section of a later version of the LGPL
 * should you choose to use a later version).
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. *)







let idiv (x:nativeint) (y:nativeint) = 
  if y = 0n  then
    raise Division_by_zero
  else Nativeint.div x y

let imod (x : nativeint) (y:nativeint) = 
  if y = 0n then
    raise Division_by_zero
  else Nativeint.rem x  y


let caml_bswap16 (x : nativeint) = 
 let open Nativeint in 
 logor (shift_left (logand x 0x00ffn) 8)
    (shift_right_logical (logand x 0xff00n) 8)

let caml_int32_bswap (x : nativeint) = 
  let open Nativeint in 
  logor (shift_left (logand x  0x000000FFn) 24)
     (logor (shift_left (logand x  0x0000FF00n)  8)
        (logor (shift_right_logical (logand x  0x00FF0000n)  8) 
      (shift_right_logical (logand x  0xFF000000n)  24)))



let caml_nativeint_bswap = caml_int32_bswap

let imul : int32 -> int32 -> int32 = [%bs.raw{| Math.imul || function (x,y) {
  y |= 0; return ((((x >> 16) * y) << 16) + (x & 0xffff) * y)|0; 
}
|}]

==> bs-platform-5.1.0.tgz: package/jscomp/runtime/caml_int32.ml <==
(* Copyright (C) 2015-2016 Bloomberg Finance L.P.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * In addition to the permissions granted to you by the LGPL, you may combine
 * or link a "work that uses the Library" with a publicly distributed version
 * of this file to produce a combined library or application, then distribute
 * that combined work under the terms of your choosing, with no requirement
 * to comply with the obligations normally placed on you by section 4 of the
 * LGPL version 3 (or the corresponding section of a later version of the LGPL
 * should you choose to use a later version).
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. *)






let div (x:nativeint) (y:nativeint) = 
  if y = 0n  then
    raise Division_by_zero
  else Caml_nativeint_extern.div x y

let mod_ (x : nativeint) (y:nativeint) = 
  if y = 0n then
    raise Division_by_zero
  else Caml_nativeint_extern.rem x  y


let caml_bswap16 (x : nativeint) = 
 let open Caml_nativeint_extern in 
 logor (shift_left (logand x 0x00ffn) 8)
    (shift_right_logical (logand x 0xff00n) 8)

let caml_int32_bswap (x : nativeint) = 
  let open Caml_nativeint_extern in 
  logor (shift_left (logand x  0x000000FFn) 24)
     (logor (shift_left (logand x  0x0000FF00n)  8)
        (logor (shift_right_logical (logand x  0x00FF0000n)  8) 
      (shift_right_logical (logand x  0xFF000000n)  24)))



let caml_nativeint_bswap = caml_int32_bswap

(* -FIXME not polyfill any more in next release *)
let imul : int32 -> int32 -> int32 = [%bs.raw{| Math.imul || function (x,y) {
  y |= 0; return ((((x >> 16) * y) << 16) + (x & 0xffff) * y)|0; 
}
|}]
